/** @file
 * @brief DYNDNS Service class header. This class represents the DYNDNS service.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef SERVICE_DYNDNS_H
#define SERVICE_DYNDNS_H

#include <string>

#include "service.h"
#include "logger.h"

#include <boost/serialization/array.hpp>
#include <boost/shared_ptr.hpp>
#include <list>

class SERVICE_DYNDNS : public Service
{

private:

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & ar, const unsigned int version);

    std::string BaseUrl;

    HTTPHelper::Ptr HTTPHelp;

    std::string assemble_base_url(const std::string& fqhn) const;

public:

    typedef boost::shared_ptr<SERVICE_DYNDNS> Ptr;

    SERVICE_DYNDNS();

    SERVICE_DYNDNS(const std::string& _protocol, const std::string& _hostname, const std::string& _login, const std::string& _password, const Logger::Ptr& _logger, const int _update_interval, const int _max_updates_within_interval, const int dns_cache_ttl, const std::string& proxy, const int proxy_port);

    ~SERVICE_DYNDNS();

    int perform_update(const std::string& ip);

};

#endif
