/** @file
 * @brief DYNS Service class header. This class represents the DYNS service.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef SERVICE_DYNS_H
#define SERVICE_DYNS_H

#include <string>

#include "service.h"
#include "logger.h"

#include <boost/serialization/array.hpp>
#include <boost/shared_ptr.hpp>
#include <list>

class SERVICE_DYNS : public Service
{

private:

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & ar, const unsigned int version);

    std::string BaseUrl;

    HTTPHelper::Ptr HTTPHelp;

    std::string assemble_base_url(const std::string& fqhn, const std::string& username, const std::string& password) const;

    std::string parse_status_code(const std::string& data) const;

public:

    typedef boost::shared_ptr<SERVICE_DYNS> Ptr;

    SERVICE_DYNS();

    SERVICE_DYNS(const std::string& _protocol, const std::string& _hostname, const std::string& _login, const std::string& _password, const Logger::Ptr& _logger, const int _update_interval, const int _max_updates_within_interval, const int dns_cache_ttl, const std::string& proxy, const int proxy_port);

    ~SERVICE_DYNS();

    int perform_update(const std::string& ip);
};

#endif
