/** @file
 * @brief ODS Service class implementation. This class represents the ODS service.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#include "service_ods.h"

#include <time.h>

using namespace std;


/**
 * Default Constructor, needed for object serialization.
 */
SERVICE_ODS::SERVICE_ODS()
{
}


/**
 * Constructor.
 * @param _hostname The hostname to update
 * @param _login The login name.
 * @param _password The corresponding password.
 */
SERVICE_ODS::SERVICE_ODS(const string& _protocol, const string& _hostname, const string& _login, const string& _password, const Logger::Ptr& _logger, const int _update_interval, const int _max_updates_within_interval, const int _dns_cache_ttl)
{
    if ( _update_interval == -1 )        // If _update_interval is default po::option_desc (not specified via config)
        set_update_interval(15);              // use default protocol value
    else
        set_update_interval(_update_interval);

    if ( _max_updates_within_interval == -1 )
        set_max_updates_within_interval(3);
    else
        set_max_updates_within_interval(_max_updates_within_interval);

    if ( _dns_cache_ttl == -1 )
        set_dns_cache_ttl(180);
    else
        set_dns_cache_ttl(_dns_cache_ttl);

    set_protocol(_protocol);
    set_hostname(_hostname);
    set_login(_login);
    set_password(_password);
    set_logger(_logger);
}


/**
 * Default destructor.
 */
SERVICE_ODS::~SERVICE_ODS()
{
}


/**
 * Performs the Service update.
 * @param ip IP Address to set.
 * @return 0 if all is fine, -1 otherwise.
 */
int SERVICE_ODS::perform_update(const std::string& ip)
{
    return 0;
}


/**
 * Serialize function needed by boost/serialization to define which members should be stored as the object state.
 * @param ar Archive
 * @param version Version
 */
template<class Archive>
void SERVICE_ODS::serialize(Archive & ar, const unsigned int version)
{
    ar & boost::serialization::base_object<Service>(*this);
}
